#
# spec file for package fuse-overlayfs
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuse-overlayfs
Version:        0.7.6
Release:        lp152.1.3
Summary:        FUSE implementation for overlayfs
License:        GPL-3.0-only
Group:          System/Management
URL:            https://github.com/containers/fuse-overlayfs
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse3-devel
BuildRequires:  gcc

%description
An implementation of overlay+shiftfs in FUSE for rootless containers.

%prep
%setup -q

%build
env NOCONFIGURE=1 ./autogen.sh
%configure --disable-silent-rules

%make_build

%install
%make_install INSTALL="install -p"

%files
# Binaries
%{_bindir}/fuse-overlayfs
%doc README.md
%license COPYING
%doc %{_mandir}/man1/%{name}.1.gz

%changelog
* Tue Feb  4 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v0.7.6 (bsc#1160460)
  - do not look in lower layers for the ino if there is no origin
    xattr set
  - attempt to use the file path if the operation on the fd fails
    with ENXIO
* Mon Jan 20 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v0.7.5
  - do not expose internal xattrs through listxattr and getxattr
* Fri Jan 17 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v0.7.4
  - fix fallocate for deleted files.
  - ignore O_DIRECT.  It causes issues with libfuse not using an
    aligned buffer, causing write(2) to fail with EINVAL.
  - on copyup, do not copy the opaque xattr.
  - fix a wrong lookup for whiteout files, that could happen on a
    double unlink.
* Thu Jan  9 2020 Sascha Grunert <sgrunert@suse.com>
- Update to v0.7.3
  - fix build with -fno-common
  - fix possible segmentation fault in direct_fsync()
  - use the data store to create missing whiteouts
  - after a rename, force a directory reload
* Tue Dec 17 2019 Sascha Grunert <sgrunert@suse.com>
- Update to v0.7.2
  - introduce inodes cache
  - correctly read inode for unix sockets
  - avoid hash map lookup when possible
  - use st_dev for the ino key
  - check whether writeback is supported
  - set_attrs: don't require write to S_IFREG
  - ioctl: do not reuse fi->fh for directories
  - fix skip whiteout deletion optimization
  - store the new mode after chmod
* Mon Aug 19 2019 Sascha Grunert <sgrunert@suse.com>
- Update to v0.5.1
  - support fuse writeback cache and enable it by default
  - update to latest gnulib
  - add option to disable fsync
  - add option to disable xattrs
  - add option to skip ino number check in lower layers
  - fix fd validity check
  - fix memory leak
  - fix read after free
  - fix type for flistxattr return
  - fix warnings reported by lgtm.com
  - enable parallel dirops
* Mon Jun 17 2019 Sascha Grunert <sgrunert@suse.com>
- Update to v0.4.1 (bsc#1137860):
  - create_directory: do not redeclare variable buf
  - fuse-overlayfs: accept option "dev"
  - fuse-overlayfs: add check to readdir for the node parent
  - fuse-overlayfs: add cleanup for layers
  - fuse-overlayfs: drop usage of static arrays for paths
  - fuse-overlayfs: refactor some xattrs common code
  - fuse-overlayfs: start using GCC autocleanup
  - fuse-overlayfs: use cleanup function for initializing node
  - fuse-overlays: fix interaction of unlink(2) with readdir(2)
  - main: add missing debug messages
  - main: do the unlink only after we created the temporary file
  - main: fix a fd leak
  - main: ignore EINVAL when copying xattrs
  - setattr: use fd from fi->fh for ftruncate() whenever possible
* Thu Mar 28 2019 Flavio Castelli <fcastelli@suse.com>
- Create initial package for version 0.3
